@@ -117,9 +117,10 @@ class CSSRule(cssutils.util.Base2):
         "and not its initial value.",
     )
 
-    parent = property(
-        lambda self: self._parent, doc="The Parent Node of this CSSRule or None."
-    )
+    @property
+    def parent(self):
+        """The Parent Node of this CSSRule or None."""
+        return self._parent
 
     parentRule = property(
         lambda self: self._parentRule,
@@ -161,7 +162,6 @@ class CSSRuleRules(CSSRule):
     """
 
     def __init__(self, parentRule=None, parentStyleSheet=None):
-
         super().__init__(parentRule=parentRule, parentStyleSheet=parentStyleSheet)
 
         self.cssRules = cssutils.css.CSSRuleList()
@@ -255,9 +255,7 @@ class CSSRuleRules(CSSRule):
                 tempsheet.cssRules
                 and not isinstance(tempsheet.cssRules[0], cssutils.css.CSSRule)
             ):
-                self._log.error(
-                    '{}: Invalid Rule: {}'.format(self.__class__.__name__, rule)
-                )
+                self._log.error(f'{self.__class__.__name__}: Invalid Rule: {rule}')
                 return False, False
             rule = tempsheet.cssRules[0]
 
@@ -268,9 +266,7 @@ class CSSRuleRules(CSSRule):
             return True, True
 
         elif not isinstance(rule, cssutils.css.CSSRule):
-            self._log.error(
-                '{}: Not a CSSRule: {}'.format(rule, self.__class__.__name__)
-            )
+            self._log.error(f'{rule}: Not a CSSRule: {self.__class__.__name__}')
             return False, False
 
         return rule, index
