@@ -5,18 +5,13 @@ from . import test_cssrule
 import cssutils.css
 
 
-class CSSCommentTestCase(test_cssrule.CSSRuleTestCase):
-    def setUp(self):
-        super(CSSCommentTestCase, self).setUp()
+class TestCSSComment(test_cssrule.TestCSSRule):
+    def _setup_rule(self):
         self.r = cssutils.css.CSSComment()
         self.rRO = cssutils.css.CSSComment(readonly=True)
         self.r_type = cssutils.css.CSSComment.COMMENT
         self.r_typeString = 'COMMENT'
 
-    def test_init(self):
-        "CSSComment.type and init"
-        super(CSSCommentTestCase, self).test_init()
-
     def test_csstext(self):
         "CSSComment.cssText"
         tests = {
@@ -64,11 +59,5 @@ class CSSCommentTestCase(test_cssrule.CSSRuleTestCase):
         s = cssutils.css.CSSComment(cssText=text)
 
         s2 = eval(repr(s))
-        self.assertTrue(isinstance(s2, s.__class__))
-        self.assertTrue(text == s2.cssText)
-
-
-if __name__ == '__main__':
-    import unittest
-
-    unittest.main()
+        assert isinstance(s2, s.__class__)
+        assert text == s2.cssText
