@@ -7,12 +7,12 @@ import pytest
 
 
 class TestCSSStyleSheet(basetest.BaseTestCase):
-    def setup(self):
+    def setup_method(self):
         self.r = cssutils.css.CSSStyleSheet()  # used by basetest
         self.s = self.r  # used here
         self.rule = cssutils.css.CSSStyleRule()
 
-    def teardown(self):
+    def teardown_method(self):
         cssutils.ser.prefs.useDefaults()
 
     def test_init(self):
@@ -318,7 +318,7 @@ ex2|x {
         # __contains__
         assert '' in s.namespaces
         assert 'ex2' in s.namespaces
-        assert not ('NOTSET' in s.namespaces)
+        assert "NOTSET" not in s.namespaces
         # __delitem__
         with pytest.raises(xml.dom.NoModificationAllowedErr):
             s.namespaces.__delitem__('ex2')
