@@ -9,10 +9,10 @@ class TestPreferences(basetest.BaseTestCase):
     testcases for cssutils.serialize.Preferences
     """
 
-    def setup(self):
+    def setup_method(self):
         cssutils.ser.prefs.useDefaults()
 
-    def teardown(self):
+    def teardown_method(self):
         cssutils.ser.prefs.useDefaults()
 
     #    def testkeepUnkownAtRules(self):
@@ -631,10 +631,10 @@ class TestCSSSerializer:
     testcases for cssutils.CSSSerializer
     """
 
-    def setup(self):
+    def setup_method(self):
         cssutils.ser.prefs.useDefaults()
 
-    def teardown(self):
+    def teardown_method(self):
         cssutils.ser.prefs.useDefaults()
 
     def test_canonical(self):
@@ -661,7 +661,6 @@ class TestCSSSerializer:
             '''00.0s''': '''0s''',
             '''00.0khz''': '''0khz''',
             '''00.0hz''': '''0hz''',
-            '''00.0khz''': '''0khz''',
             '''00.0deg''': '''0deg''',
             '''00.0rad''': '''0rad''',
             '''00.0grad''': '''0grad''',
