@@ -1,7 +1,7 @@
 """Testcases for cssutils.util"""
 
 
-import cgi
+from email.message import Message
 import re
 import urllib.request
 import urllib.error
@@ -31,14 +31,14 @@ class ListSeqTestCase:
         # len
         assert 2 == len(ls)
         # __contains__
-        assert True == (1 in ls)
+        assert True is (1 in ls)
         # get
         assert 1 == ls[0]
         assert 2 == ls[1]
         # del
         del ls[0]
         assert 1 == len(ls)
-        assert False == (1 in ls)
+        assert False is (1 in ls)
         # for in
         for x in ls:
             assert 2 == x
@@ -384,9 +384,11 @@ class _readUrl_TestCase:
             def __init__(self, url, contenttype, content, exception=None, args=None):
                 self.url = url
 
-                mt, params = cgi.parse_header(contenttype)
-                self.mimetype = mt
-                self.charset = params.get('charset', None)
+                m = Message()
+                m['content-type'] = contenttype
+
+                self.mimetype = m.get_content_type()
+                self.charset = m.get_param('charset', None)
 
                 self.text = content
 
@@ -400,7 +402,6 @@ class _readUrl_TestCase:
                 mimetype, charset = self.mimetype, self.charset
 
                 class Info:
-
                     # py2x
                     def gettype(self):
                         return mimetype
@@ -502,7 +503,7 @@ class _readUrl_TestCase:
 class TestLazyRegex:
     """Tests for cssutils.util.LazyRegex."""
 
-    def setup(self):
+    def setup_method(self):
         self.lazyre = LazyRegex('f.o')
 
     def test_public_interface(self):
